WOITextButton class

A simple text button that can be used as a capsule or rectangular button

Here is how you can use the widget


WOITextButton(
  text: 'Submit',
  onTap: (){},
)

Text Button

Inheritance

Constructors

WOITextButton({Key? key, VoidCallback? onTap, double? heigth, double? width, bool isDisabled = false, WOIButtonStyle? buttonStyle, required String text, TextStyle? textStyle})
The all in one button
const

Properties

buttonStyle → WOIButtonStyle?
This provides multiple option to style your button Furthure it gives you option to change add Icons as a prifix and suffix as well
final
hashCode → int
The hash code for this object.
no setterinherited
heigth → double?
Define the height of the button
final
isDisabled → bool
If the button should be tapable or not
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTap → VoidCallback?
On Tap action for the Button
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
Text String to be displayed
final
textStyle → TextStyle?
To change the text style for the text
final
width → double?
Define the width of the button, by default it would be expanded and
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited